Filter

Trait Filter 

pub trait Filter: Source + Sink { }
An element with both an input and an output — decoder, encoder, filter, thumbnail extractor, … Just a name for “has a Sink to receive and a Source to push what it produces into”; nothing new to implement beyond those two.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: Source + Sink> Filter for T